@@ -35,7 +35,8 @@ tsp_two_opt <- function(x, control = NULL){
     xx <- as.matrix(x)
 
     if(rep > 1) {
-        tour <- replicate(rep, .Call("two_opt", xx, initial(), PACKAGE="TSP"), 
+        tour <- replicate(rep, .Call("two_opt", xx, initial(), 
+          PACKAGE="TSP"), 
             simplify = FALSE)
         lengths <- sapply(tour, FUN = function(t) tour_length(x, t))
         tour <- tour[[which.min(lengths)]]
